function [bins,fhat] = HistOptBin(dat)
% function [bins,fhat] = HistOptBin(dat)
% computes the histogram of dat with optimal bin width 
% computed from inter-quartile range using freedman-diaconis rule
% see http://en.wikipedia.org/wiki/Freedman%E2%80%93Diaconis_rule
%
% input:
%  dat: a 1D vector with the data
% outputs:
%  bins: the values for the boundaries of the bins
%  fhat: the histogram with these bins normalized so sum(fhat) = 1
% REA 5/3/04-4/7/05

dat = sort(dat(:));

ndat = numel(dat);

iqrange = dat(round(0.75*ndat)) - dat(round(0.25*ndat));
if iqrange==0
    iqrange = eps;
end

h = 2*iqrange*ndat^(-1/3); % bin width by freedman-diaconis rule

bins = min(dat)-h:h:max(dat) + h;

vk = histc(dat,bins);
fhat = vk/(sum(vk)); %normalize so sums to 1