% P17Deadtime2.m Energy spectrum with deadtime
% COPYRIGHT:  Aprend Technology, 2011. All rights reserved.
 
%% set path--change for your system
workdir = 'E:\Projects\CountDetPhysics\PileupSim\';
addpath(workdir);

%% Create the spectrum
tube_voltage = 120; % keV  
[specnum,xray_energies,specdat] = XrayTubeSpectrumTasmip(tube_voltage,'number_spectrum','clipzeros');


%%  MC sim of spectrum
etas = [0.6 1e6*100e-9];
npulses2gen = 1e6;
mean_cps = 1e6; % seconds
t_ave = 1/mean_cps;%sec
fh = figure;
kpanel = 1;
for eta = etas
    deadtime = eta/mean_cps; % eta set in prev cell
    t_integrate = 1e6; %sec--Set thsi so get energies for all pulses
    egys = EgysWithPileup(specdat,'mean_cps',mean_cps,'deadtime',deadtime, ...
        'npulses2gen',npulses2gen,'t_integrate',t_integrate);
    
            %  compare MC results to theory
    sp_w_pileup = SpectrumWithPileup(specdat,eta);
    [bins,fhat] = HistOptBin(egys(:));
    fhatn = fhat*max(sp_w_pileup.specnum)/max(fhat);
             %   make the plot
    subplot(1,2,kpanel)
    kpanel = kpanel + 1;      
    hold on
    plot(bins,fhatn,'--k','linewidth',1.5); % MC data
    plot(sp_w_pileup.egys,sp_w_pileup.specnum,'-r','linewidth',1.5); % theory
    plot(xray_energies,specnum*max(sp_w_pileup.specnum)/max(specnum),'-b','linewidth',1.5); % original spectrum
    str = ['\eta = ' num2str(eta)];
    ht = text(0.3*max(sp_w_pileup.egys),0.6*max(sp_w_pileup.specnum), str);
    set(ht,'fontsize',14);
    hold off
    if kpanel==2
        legend('Monte Carlo','theory','input spectrum'); %,'location','southwest'); 
    end
    xlabel('x-ray photon energy (keV)','fontsize',14,'interpreter','none')
    ylabel('spectrum','fontsize',14)
    set(gca,'fontsize',12,'linewidth',1.5)
end
set(fh,'color','w','position',[250 250 750 375])

%% export the figure as png and eps
% dirname = 'E:\Projects\Blog\Posts\P17Deadtime2\'; % edit this for your computer
dirname = 'E:/Projects/Blog/Posts/P17Deadtime2/';
figno = sprintf('-f%d',fh);
fname = 'SpectrumWDeadtime';
   % export as eps
exportfig(fh,[dirname fname '.eps'],'width',6,'LockAxes',0,'color','cmyk');
set(fh,'papertype','usletter')
print(figno,'-dpng','-cmyk','-r100',[dirname fname '.png']) % resolution 100 dpi
